SystemOrganization addCategory: #'SOUL-UI'!

Object subclass: #SOULClauseBrowser
	instanceVariableNames: 'browser'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOUL-UI'!

!SOULClauseBrowser class methodsFor: 'opening' stamp: 'AndyKellens 12/18/2009 11:16'!
open
	^self new open! !

!SOULClauseBrowser class methodsFor: 'class initialization' stamp: 'ReinoutStevens 11/7/2011 14:58'!
registerInMenu: aBuilder
	<worldMenu>
	(aBuilder item:#'SOUL Clause Browser')
		parent:#Tools; 
		action:[self open];
		icon: (UITheme current soulClauseIcon )
	! !

!SOULClauseBrowser methodsFor: 'private actions layer' stamp: 'AndyKellens 11/30/2009 09:51'!
addLayerTo: aPresentation 
	| newlayername layer newlayer |
	layer := aPresentation selection.
	newlayername := self requestNameForLayer.
	(newlayername isNil or: [newlayername = '']) ifTrue: [^self].
	(Smalltalk at: newlayername asSymbol ifAbsent: [nil]) ifNil: 
			[newlayer := layer 
						subclass: newlayername asSymbol
						instanceVariableNames: ''
						classVariableNames: ''
						poolDictionaries: ''
						category: layer category.
			newlayer initPredicateMappings]
		ifNotNil: [^self warnClassAlreadyExists: newlayername].
	(self selectedLayer: newlayer)
	
	! !

!SOULClauseBrowser methodsFor: 'private actions protocol' stamp: 'AndyKellens 11/30/2009 09:59'!
addProtocol: aPresentation
	| layer protocolName |
	layer := aPresentation entity.
	protocolName := self requestNameForProtocol.
	(protocolName isNil or: [protocolName = '']) ifTrue: [^self].
	layer addProtocol:(protocolName asSymbol).
	self selectedProtocol: (protocolName asSymbol) inLayer: layer

	

	! !

!SOULClauseBrowser methodsFor: 'private actions editor' stamp: 'AndyKellens 11/30/2009 13:08'!
assertRule: aRule
	|clause selectedLayer selectedClause selectedProtocol|
	selectedLayer := aRule entity at:1.
	selectedProtocol := aRule entity at:2.
	selectedClause := aRule entity at:3.
	clause := self clausesInText: aRule ifError:[^self].
 	
	selectedLayer assertClause: clause inProtocol: selectedProtocol ifAlreadyClassified:
			[ :key :currentProtocol :newProtocol |
				self halt.
			].
	self selectedRule: clause inProtocol: selectedProtocol ofLayer: selectedLayer! !

!SOULClauseBrowser methodsFor: 'building' stamp: 'AndyKellens 11/24/2009 15:20'!
browser
	browser := GLMTabulator new.
	browser title:'SOUL Clause Browser'.
	browser row:[:row |
		row 
			column:#layer;
			column:#protocol;
			column:#predicate;
			column:#rule].
	browser row: #source.
	
	self showLayers.
	self showProtocols.
	self showPredicates.
	self showRules.
	self showSource.
	^browser! !

!SOULClauseBrowser methodsFor: 'private' stamp: 'AndyKellens 11/4/2011 14:56'!
clausesInText: aTextPresentation ifError: errorBlock 
	|  soulprogram clauses position |
	
	soulprogram := SoulFactory current makeParser parse: (aTextPresentation text asString)
				onError: 
					[:text :pos | 
					| layer protocol rule errorString|
					layer := aTextPresentation entity at:1.
					protocol := aTextPresentation entity at:2.
					rule := aTextPresentation entity at:3.
					position := pos > aTextPresentation text size ifTrue:[aTextPresentation text size] ifFalse:[pos].
					errorString := aTextPresentation text replaceFrom:position to:position with:(aTextPresentation text at: position ifAbsent:['']) asString,'<--', text.
					self selectedRule: (SoulUIParseErrorWrapper rule: rule errorString:errorString) inProtocol: protocol ofLayer: layer.
					^errorBlock value].
	(self isProgram: soulprogram) 
		ifFalse: [self error: 'Input can not be a query!!'].
	clauses := soulprogram clauses.
	"self checkForUnknownPredicatesIn: clauses onCancel: errorBlock.
	self checkForUnusedVariablesIn: clauses onCancel: errorBlock."
	^clauses first
! !

!SOULClauseBrowser methodsFor: 'private interface' stamp: 'AndyKellens 11/30/2009 11:41'!
editorPane
	^browser paneNamed:#source! !

!SOULClauseBrowser methodsFor: 'private' stamp: 'AndyKellens 11/25/2009 10:49'!
isProgram: aProgram
	^ aProgram isKindOf: ProgramSequence! !

!SOULClauseBrowser methodsFor: 'private interface' stamp: 'AndyKellens 11/30/2009 09:55'!
layerPane
	^browser paneNamed:#layer! !

!SOULClauseBrowser methodsFor: 'private actions rules' stamp: 'AndyKellens 11/30/2009 11:25'!
moveRuleDown: aPresentation
	| layer rule protocol |
	layer := aPresentation entity at:1.
	protocol := aPresentation entity at:3.
	rule := aPresentation selection.
	layer moveClauseDown: rule.
	self selectedRule: rule inProtocol: protocol ofLayer: layer! !

!SOULClauseBrowser methodsFor: 'private actions rules' stamp: 'AndyKellens 11/30/2009 11:25'!
moveRuleUp: aPresentation
	| layer rule protocol |
	layer := aPresentation entity at:1.
	protocol := aPresentation entity at:3.
	rule := aPresentation selection.
	layer moveClauseUp: rule.
	self selectedRule: rule inProtocol: protocol ofLayer: layer! !

!SOULClauseBrowser methodsFor: 'opening' stamp: 'AndyKellens 11/27/2009 15:07'!
open
	self browser openOn:LogicStorage ! !

!SOULClauseBrowser methodsFor: 'private interface' stamp: 'AndyKellens 11/30/2009 10:25'!
predicatePane
	^browser paneNamed:#predicate! !

!SOULClauseBrowser methodsFor: 'private interface' stamp: 'AndyKellens 11/30/2009 09:57'!
protocolPane
	^browser paneNamed:#protocol! !

!SOULClauseBrowser methodsFor: 'private actions layer' stamp: 'AndyKellens 11/30/2009 09:58'!
removeLayer: aPresentation 
	| newlayername layer newlayer |
	layer := aPresentation selection.
	(UITheme current 
		questionWithoutCancelIn: UIManager default modalMorph
		text: 'Delete the layer?'
		title: 'Delete layer') ifTrue: [layer removeFromSystem].
	self selectedLayer: layer superclass! !

!SOULClauseBrowser methodsFor: 'private actions predicates' stamp: 'AndyKellens 11/30/2009 10:37'!
removePredicate: aPresentation 
	| layer sel |
	layer := aPresentation entity at:1.
	sel := aPresentation selection.
	sel isNil 
		ifFalse: 
			[(UITheme current 
				questionWithoutCancelIn: UIManager default modalMorph
				text: 'Delete the predicate?'
				title: 'Delete predicate') 
					ifTrue: [layer retractClausesWithPredicateKey: sel.
						self selectedPredicate: nil inProtocol: (aPresentation entity at:2) ofLayer: layer
						]]! !

!SOULClauseBrowser methodsFor: 'private actions protocol' stamp: 'AndyKellens 11/30/2009 10:03'!
removeProtocol: aPresentation
	| layer protocol |
	layer := aPresentation entity.
	protocol := aPresentation selection.
	layer removeProtocol: protocol.
	self selectedProtocol: nil inLayer: layer ! !

!SOULClauseBrowser methodsFor: 'private actions rules' stamp: 'AndyKellens 11/30/2009 11:29'!
removeRule: aPresentation 
	| layer rule protocol |
	layer := aPresentation entity at: 1.
	protocol := aPresentation entity at:3.
	rule := aPresentation selection.
	(UITheme current 
		questionWithoutCancelIn: UIManager default modalMorph
		text: 'Delete the rule?'
		title: 'Delete rule') ifTrue: [layer retractClause: rule.
			self selectedRule: nil inProtocol: protocol ofLayer: layer
			
			]! !

!SOULClauseBrowser methodsFor: 'private actions layer' stamp: 'AndyKellens 11/25/2009 16:59'!
requestNameForLayer
		^(UITheme 
			current 
				textEntryIn: (UIManager default modalMorph) 
				text: 'Name for layer' title: 'Add layer' entryText: '')! !

!SOULClauseBrowser methodsFor: 'private actions protocol' stamp: 'AndyKellens 11/26/2009 10:49'!
requestNameForProtocol
		^(UITheme 
			current 
				textEntryIn: (UIManager default modalMorph) 
				text: 'Name for protocol' title: 'Add protocol' entryText: '')! !

!SOULClauseBrowser methodsFor: 'private interface' stamp: 'AndyKellens 11/30/2009 10:24'!
rulePane
	^browser paneNamed:#rule! !

!SOULClauseBrowser methodsFor: 'private interface' stamp: 'AndyKellens 11/30/2009 09:55'!
selectedLayer: aLayer
	| pane |
	pane := self layerPane.
	(pane port:#entity) value: nil.
	(pane port:#entity) value: LogicStorage.
	(pane port:#selection ) value: aLayer
	! !

!SOULClauseBrowser methodsFor: 'private interface' stamp: 'AndyKellens 11/30/2009 10:49'!
selectedPredicate: aPredicate inProtocol: aProtocol ofLayer: aLayer
	| pane key|
	self selectedProtocol: aProtocol inLayer: aLayer. 
	pane := self predicatePane.
	key := aPredicate ifNil:[nil] ifNotNil:[aLayer predicateKeyofClause: aPredicate].
	(pane port:#entity) value: nil.
	(pane port:#entity) value:(GLMMultiValue new add: aLayer; add: aProtocol;yourself).
	
	(pane port:#selection) value: key
	! !

!SOULClauseBrowser methodsFor: 'private interface' stamp: 'AndyKellens 11/30/2009 10:35'!
selectedProtocol: aProtocol inLayer: aLayer
	| pane |
	self selectedLayer: aLayer.
	pane := self protocolPane.
	(pane port:#entity) value: nil.
	(pane port:#entity) value: aLayer.
	(pane port:#selection ) value: aProtocol
	! !

!SOULClauseBrowser methodsFor: 'private interface' stamp: 'AndyKellens 11/30/2009 11:26'!
selectedRule: aRule inProtocol: aProtocol ofLayer: aLayer
	| pane key conclusion |
	conclusion := aRule ifNil:[nil] ifNotNil:[aRule conclusion].
	self selectedPredicate: conclusion inProtocol: aProtocol ofLayer: aLayer.
	key := aRule ifNil:[nil] ifNotNil: [aLayer predicateKeyofClause: aRule].
	pane := self rulePane.
	(pane port:#entity) value: nil.
	(pane port:#entity) value:(GLMMultiValue new add: aLayer; add: key; add:aProtocol; yourself).
	(pane port:#selection) value:aRule
	! !

!SOULClauseBrowser methodsFor: 'private interface' stamp: 'AndyKellens 11/30/2009 13:06'!
selectedSource: aText ofRule: aRule inProtocol: aProtocol ofLayer: aLayer
	| pane |
	self selectedRule: aRule inProtocol: aProtocol ofLayer: aLayer.
	pane := self editorPane.
	(pane port:#entity) value: nil.
	(pane port:#text) value: aText.
	(pane port:#entity) value:(GLMMultiValue new add: aLayer; add: aProtocol; add:aRule; yourself)
	! !

!SOULClauseBrowser methodsFor: 'private' stamp: 'AndyKellens 11/27/2009 15:08'!
showLayers
	browser
		showOn:#layer;
		from: #outer->#entity;
		using:[
			browser 
				tree 
					children:[:layer | layer subclasses];
					act:[:layer | self addLayerTo:layer] entitled:'Add layer';
					act:[:layer | self removeLayer:layer] entitled:'Remove layer'
				
			]! !

!SOULClauseBrowser methodsFor: 'private' stamp: 'AndyKellens 11/26/2009 11:26'!
showPredicates
	browser
		showOn:#predicate;
		from:#layer;
		from:#protocol;
		using:[
			browser 
				list
					act:[:presentation | self removePredicate: presentation] entitled:'Remove predicate'; 
					display:[:layer :protocol| layer predicateKeysIn: protocol]]! !

!SOULClauseBrowser methodsFor: 'private' stamp: 'AndyKellens 11/27/2009 15:45'!
showProtocols
	browser
		showOn:#protocol;
		from:#layer;
		using:[
			browser 
				list display:[:layer | layer protocols];
				act:[:presentation| self addProtocol: presentation] entitled:'Add protocol';
				act:[:presentation | self removeProtocol: presentation] entitled:'Remove protocol']! !

!SOULClauseBrowser methodsFor: 'private' stamp: 'AndyKellens 11/30/2009 11:25'!
showRules
	browser
		showOn:#rule;
		from:#layer;
		from:#predicate;
		from:#protocol;
		using:[
			browser 
				list 
					display:[:layer :predicate :protocol| (layer clausesForPredicateKey: predicate)];
					format:[:rule | rule conclusion asString];
					act:[:presentation | self removeRule: presentation] entitled:'Remove rule';
					act:[:presentation | self moveRuleUp: presentation] entitled:'Move rule up';
					act:[:presentation | self moveRuleDown: presentation] entitled:'Move rule down'
					]! !

!SOULClauseBrowser methodsFor: 'private' stamp: 'tg 6/12/2010 16:24'!
showSource
		browser
		showOn:#source;
		from:#layer;
		from:#protocol;
		from:#rule;
		using:[
			browser text useExplicitNotNil;
							display:[:layer :protocol :rule |rule];
							format:[:rule  | rule ifNil:[''] ifNotNil:[rule asPrettyString]];
							when:[:layer :protocol :rule | layer notNil & protocol notNil];
							act:[:source | self assertRule: source] on: $t entitled:'Assert';
							act:[:source | self updateRule: source] on: $u entitled:'Update']! !

!SOULClauseBrowser methodsFor: 'private actions editor' stamp: 'AndyKellens 11/30/2009 17:01'!
updateRule: aRule
	|clause selectedLayer selectedClause selectedProtocol|
	selectedLayer := aRule entity at:1.
	selectedProtocol := aRule entity at:2.
	selectedClause := aRule entity at:3.
	(selectedClause isKindOf:SoulUIParseErrorWrapper) ifTrue:[selectedClause := selectedClause rule].
	clause := self clausesInText: aRule ifError:[^self].
	selectedLayer replaceClause: selectedClause with: clause inProtocol: selectedProtocol.
	self selectedRule: clause inProtocol: selectedProtocol ofLayer: selectedLayer
	! !

!SOULClauseBrowser methodsFor: 'private actions layer' stamp: 'AndyKellens 11/25/2009 17:04'!
warnClassAlreadyExists: aString
		^(UITheme 
			current 
				abortIn: (UIManager default modalMorph) 
				text: 'Class ', aString, ' already exists' title: 'Warning')! !

Object subclass: #SOULQueryBrowser
	instanceVariableNames: 'browser bindingList'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOUL-UI'!

!SOULQueryBrowser class methodsFor: 'opening' stamp: 'AndyKellens 12/18/2009 11:15'!
open
	^self new open! !

!SOULQueryBrowser class methodsFor: 'class initialization' stamp: 'ReinoutStevens 11/7/2011 14:58'!
registerInMenu: aBuilder
	<worldMenu>
	(aBuilder item:#'SOUL Query Browser')
		parent:#Tools; 
		action:[self open];
		icon: (UITheme current soulQueryIcon )
	! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'AndyKellens 11/4/2011 15:09'!
allRepositories
	^SoulFactory repositoryNames asOrderedCollection ! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'AndyKellens 12/17/2009 11:55'!
allResults
	| query variables|
	query := (self queryPane port:#soulquery) value.
	query ifNil:[^self askToAccept].
	query allResults.
	(self queryPane port:#results) value: query results.
	variables := ((self queryPane port:#variables) value select:[:variable | variable isEnabled]) collect:[:variableW | variableW variable].
	self makeBindingList
	! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'AndyKellens 12/2/2009 14:20'!
askToAccept
	(UITheme current 
		questionWithoutCancelIn: UIManager default modalMorph
		text: 'Query not accepted'
		title: 'Accept first?') ifTrue:[self parseQuery]! !

!SOULQueryBrowser methodsFor: 'building' stamp: 'AndyKellens 6/9/2010 15:46'!
browser
	browser := GLMTabulator new.
	browser title:'SOUL Query Browser'.
	browser row:[:row |
		row 
			column:#query span:3;
			column:[:column |
				column row:#variables.
				column 
					row:#repository span:0.15]].
	browser row: #results.
	browser act: [:f | self nextResult] icon: MenuIcons smallDoItIcon entitled: 'Next result'.
	browser act: [:f | self allResults] icon: MenuIcons smallForwardIcon entitled: 'All results'.
	self showRepositories.
	self showQuery.
	self showVariables.
	self showResults.
	^browser! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'AndyKellens 12/17/2009 12:20'!
getVariables
	^(self variablesPane port:#entity) value! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'JohanBrichau 9/29/2010 09:47'!
makeBindingList
	| root current theResult variables|
	theResult := (self queryPane port:#results) value.
	theResult ifNotNil:[
	variables := ((self queryPane port:#variables) value select:[:variable | variable isEnabled]) collect:[:variableW | variableW variable].
	root := SoulBindingWrapper onObject:nil.
	current := root.
	theResult doCollection:[:result |
			result do:[:binding |
				current := current bindingFor: binding value.			
				].
			current := root] forVariables: variables.
	(self queryPane port:#bindings) value: root]! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'AndyKellens 12/17/2009 11:59'!
moveVariableDown: aPresentation
	| selectedVariable variables index |
	selectedVariable := aPresentation selection.
	variables := (self queryPane port:#variables) value.
	index := variables indexOf: selectedVariable.
	index = (variables size) ifFalse:[
		variables swap: index with: (index + 1)
		].
   (self queryPane port:#variables) value: nil. "Trigger an update"
   (self queryPane port:#variables) value: variables.
   self makeBindingList 
	
! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'AndyKellens 12/17/2009 11:59'!
moveVariableUp: aPresentation
	| selectedVariable variables index |
	selectedVariable := aPresentation selection.
	variables := (self queryPane port:#variables) value.
	index := variables indexOf: selectedVariable.
	index = 1 ifFalse:[
		variables swap: index with: (index - 1)
		].
   (self queryPane port:#variables) value: nil. "Trigger an update"
   (self queryPane port:#variables) value: variables.
 	self makeBindingList
	! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'AndyKellens 12/17/2009 11:56'!
nextResult
	| query previous variables |
	query := (self queryPane port:#soulquery) value.
	query ifNil:[^self askToAccept].
	previous := query nextResult.
	(self queryPane port:#results) value: query results.
	self makeBindingList
	! !

!SOULQueryBrowser methodsFor: 'opening' stamp: 'AndyKellens 6/9/2010 15:45'!
open
	self browser openOn:''.
	self setInitialValues! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'AndyKellens 11/4/2011 15:10'!
parseQuery
	| position errorString tree variables query|
	query := (self queryPane port:#text) value.
	tree := SoulFactory current makeParser parse: 'if ' , query
		onError: 
			[:text :pos | 
			position := pos > query size ifTrue: [query size] ifFalse: [pos].
			errorString := query asText 
						replaceFrom: position
						to: position
						with: (query at: position ifAbsent: ['']) asString , '<--' , text.
			(self queryPane port:#entity) value: nil.
			(self queryPane port:#entity) value: errorString.
			(self queryPane port:#variables) value: OrderedCollection new.
			(self queryPane port:#results) value:nil.
			^nil].
		variables := (tree fetchVariables 
				select: [:var | (var isKindOf: HiddenVariable) not]).
	variables := variables collect:[:variable | SoulUIVariableWrapper variable: variable].
	(self queryPane port:#soulquery) value:(SoulEvaluator evalQuery: tree in:(SoulFactory repository: (self repositoryPane port:#selection) value)).
	(self queryPane port:#variables) value: variables.
	^tree! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'AndyKellens 12/1/2009 14:21'!
queryPane
	^browser paneNamed:#query! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'AndyKellens 6/9/2010 15:10'!
repositoryPane
	^browser paneNamed:#repository! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'AndyKellens 6/9/2010 15:44'!
setInitialValues 
	(self repositoryPane port:#selection) value: (self allRepositories first)! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'AndyKellens 6/9/2010 15:44'!
showQuery
	browser
		showOn:#query;
		using:[
			browser 
				text
					act:[:presentation | self parseQuery] on:$s entitled:'Accept']! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'AndyKellens 6/9/2010 15:31'!
showRepositories
	browser
		showOn:#repository;
		using:[
			browser 
				 dropDownList
           				 display: (self allRepositories);
            			 format:[ :each| each asString ];
           		 		 selectedIndex: 1 ].
! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'AndyKellens 6/9/2010 15:09'!
showResults
	browser
		showOn:#results;
		from:#query->#bindings;
		from:#query->#results;
		using:[| finder  |
			browser
				text
				 title:'Textual';
				 display:[:bindings :results| results asString];
				 when:[:bindings :results | results isNil not].
			browser 
				tree
				  title:'Bindings';
				  display:[:bindings :results| |toShow vars|
						toShow := OrderedCollection new.
						vars := ((self getVariables) select:[:var | var isEnabled]) collect:[:var | var variable].
						results doCollection:[:res | toShow add: (SoulUIResultWrapper result: res variables: vars)] forVariables: vars.
						toShow];
				  act:[:presentation | |selection |
						selection := presentation selection.
						selection inspect] entitled:'Inspect';
				  when:[:results :variables | results isNil not];
				  children:[:res | (res isKindOf:SoulUIResultWrapper) ifTrue: [res bindings]].
			finder := browser custom:(GLMFinder new).
			finder title:'Results'.
			finder
					list
						display:[:bindings | bindings bindings values];
						format:[:binding | binding object asString];
						when:[:binding | binding bindings values isEmpty not]
			
			]
					! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'AndyKellens 6/9/2010 15:07'!
showVariables
	browser
		showOn:#variables;
		using:[
			browser 
				list ].
	browser
		showOn:#variables;
		from:#query->#variables;
		using:[
			browser 
				list
					act:[:presentation | self moveVariableUp: presentation] entitled:'Move up';
					act:[:presentation | self moveVariableDown: presentation] entitled:'Move down';
					act:[:presentation | self toggleVariable: presentation] entitled:'Toggle'.
					
				] ! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'AndyKellens 12/17/2009 11:57'!
toggleVariable: aPresentation
	|variables |
	variables := (self queryPane port:#variables) value.
	aPresentation selection toggle.
	(self queryPane port:#variables) value: nil. "Force an update"
   (self queryPane port:#variables) value: variables.
   self makeBindingList ! !

!SOULQueryBrowser methodsFor: 'private' stamp: 'AndyKellens 12/17/2009 12:19'!
variablesPane
	^browser paneNamed:#variables! !

Object subclass: #SoulBindingWrapper
	instanceVariableNames: 'object bindings'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOUL-UI'!

!SoulBindingWrapper class methodsFor: 'instance creation' stamp: 'AndyKellens 12/4/2009 15:45'!
onObject: anObject
	^super new initializeWithObject: anObject! !

!SoulBindingWrapper methodsFor: 'bindings' stamp: 'AndyKellens 12/4/2009 16:17'!
bindingFor: anObject
	^bindings at: anObject ifAbsentPut:[SoulBindingWrapper onObject: anObject]! !

!SoulBindingWrapper methodsFor: 'bindings' stamp: 'AndyKellens 12/4/2009 16:22'!
bindings
	^bindings! !

!SoulBindingWrapper methodsFor: 'initialize' stamp: 'AndyKellens 12/4/2009 16:25'!
initializeWithObject: anObject
	object := anObject.
	bindings := Dictionary new! !

!SoulBindingWrapper methodsFor: 'accessing' stamp: 'AndyKellens 12/5/2009 10:38'!
object
	^object! !

Object subclass: #SoulUIParseErrorWrapper
	instanceVariableNames: 'rule errorString'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOUL-UI'!

!SoulUIParseErrorWrapper class methodsFor: 'instance creation' stamp: 'AndyKellens 11/30/2009 13:12'!
rule: aRule errorString: aString
	^super new errorString: aString; rule: aRule! !

!SoulUIParseErrorWrapper methodsFor: 'printing' stamp: 'AndyKellens 11/30/2009 13:11'!
asPrettyString 
	^self asString! !

!SoulUIParseErrorWrapper methodsFor: 'printing' stamp: 'AndyKellens 11/30/2009 13:08'!
asString
	^errorString! !

!SoulUIParseErrorWrapper methodsFor: 'accessing' stamp: 'AndyKellens 11/30/2009 13:13'!
conclusion
	^rule ifNil:[nil] ifNotNil:[rule conclusion]! !

!SoulUIParseErrorWrapper methodsFor: 'accessing' stamp: 'AndyKellens 11/30/2009 13:08'!
errorString: aString
	errorString := aString! !

!SoulUIParseErrorWrapper methodsFor: 'accessing' stamp: 'AndyKellens 11/30/2009 13:13'!
multiplicity 
	^rule ifNil:[0] ifNotNil:[rule multiplicity]! !

!SoulUIParseErrorWrapper methodsFor: 'accessing' stamp: 'AndyKellens 11/30/2009 13:12'!
predicate
	^rule ifNil:[''] ifNotNil:[rule predicate]! !

!SoulUIParseErrorWrapper methodsFor: 'accessing' stamp: 'AndyKellens 11/30/2009 17:02'!
rule 
	^rule! !

!SoulUIParseErrorWrapper methodsFor: 'accessing' stamp: 'AndyKellens 11/30/2009 13:12'!
rule: aRule
	rule := aRule! !

Object subclass: #SoulUIResultWrapper
	instanceVariableNames: 'result variables'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOUL-UI'!

!SoulUIResultWrapper class methodsFor: 'instance creation' stamp: 'AndyKellens 12/1/2009 10:45'!
result: aResult variables: aCollection
	^super new result: aResult; variables: aCollection ! !

!SoulUIResultWrapper methodsFor: 'bindings' stamp: 'AndyKellens 12/2/2009 13:24'!
bindings
	^variables collectWithIndex:[:variable :index | (result at: index) smalltalkValue]
	! !

!SoulUIResultWrapper methodsFor: 'printing' stamp: 'AndyKellens 12/1/2009 16:40'!
printOn: aStream
	aStream nextPut:$(.
	variables do:[:var | var printOn: aStream] separatedBy:[aStream nextPut:$,].
	aStream nextPut:$)! !

!SoulUIResultWrapper methodsFor: 'accessing' stamp: 'AndyKellens 12/1/2009 10:45'!
result: aResult
	result := aResult! !

!SoulUIResultWrapper methodsFor: 'accessing' stamp: 'AndyKellens 12/1/2009 10:45'!
variables: aCollection
	variables := aCollection ! !

Object subclass: #SoulUIVariableWrapper
	instanceVariableNames: 'variable isEnabled'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOUL-UI'!

!SoulUIVariableWrapper class methodsFor: 'instance creation' stamp: 'AndyKellens 12/1/2009 16:12'!
variable: aVariable
	^super new initializeWithVariable: aVariable! !

!SoulUIVariableWrapper methodsFor: 'initialize-release' stamp: 'AndyKellens 12/1/2009 16:12'!
initializeWithVariable: aVariable
	variable := aVariable.
	isEnabled := true! !

!SoulUIVariableWrapper methodsFor: 'accessing' stamp: 'AndyKellens 12/1/2009 16:13'!
isEnabled 
	^isEnabled 
! !

!SoulUIVariableWrapper methodsFor: 'printing' stamp: 'AndyKellens 12/1/2009 16:28'!
printOn: aStream
	aStream nextPutAll: variable asString.
	self isEnabled ifFalse:[aStream nextPutAll:'(disabled)']! !

!SoulUIVariableWrapper methodsFor: 'operations' stamp: 'AndyKellens 12/1/2009 16:25'!
toggle
	isEnabled := isEnabled not! !

!SoulUIVariableWrapper methodsFor: 'accessing' stamp: 'AndyKellens 12/1/2009 16:13'!
variable 
	^variable! !
